import numpy as np
import pandas as pd
from sklearn.neighbors import KNeighborsClassifier

dataset = pd.read_csv('iris.csv')
np.random.seed(0)

iris_X = np.asmatrix(dataset[['sepal.width', 'sepal.length', 'petal.width', 'petal.length']], dtype=np.float64)
iris_y = np.asarray(dataset['variety'])
indices = np.random.permutation(len(iris_X))
iris_X_train = iris_X[indices[:-10]]
iris_y_train = iris_y[indices[:-10]]
iris_X_test = iris_X[indices[-1:]]
iris_y_test = iris_y[indices[-1:]]

knn = KNeighborsClassifier(n_neighbors=8, weights='distance', algorithm='ball_tree', leaf_size=50, p=2, metric='minkowski', n_jobs=-1)
knn.fit(iris_X_train, iris_y_train)

distances, samples = knn.kneighbors(iris_X_test, 5)
print(distances)
print(samples)
for sample in samples[0]:
    print(iris_y_train[sample])

print('*******')

predicted_proba = knn.predict_proba(iris_X_test)
print(predicted_proba)

print('********')

iris_X_test = iris_X[indices[-9:-8]]
iris_y_test = iris_y[indices[-9:-8]]
predicted_proba = knn.predict_proba(iris_X_test)
print(predicted_proba)

print('*******')

iris_X_test = iris_X[indices[-10:]]
iris_y_test = iris_y[indices[-10:]]
score = knn.score(iris_X_test, iris_y_test)
print(score)
